@@ -5,7 +5,8 @@ def setupVarious(context):
         return
 
     from Products.CMFCore.utils import getToolByName
-    qi_tool = getToolByName(context.getSite(), 'portal_quickinstaller')
+    portal = context.getSite()
+    qi_tool = getToolByName(portal, 'portal_quickinstaller')
     if not qi_tool.isProductInstalled('plone.app.iterate'):
         qi_tool.installProduct('plone.app.iterate', swallowExceptions=1)
 
@@ -14,8 +15,11 @@ def setupVarious(context):
         from Products.Five import zcml
         import ilrt.formalworkflow
         zcml.load_config('configure.zcml', ilrt.formalworkflow)
-        
-
+        # Now need to rerun the generic setup steps overridden by iterate
+        gsetup = getToolByName(portal, 'portal_setup')
+        gsetup.manage_importSelectedSteps(context_id='profile-ilrt.formalworkflow:formalworkflow',
+                                              ids=['actions','workflow'],
+                                              run_dependencies=True)
 
     
 
